import 'package:comunic/models/api_request.dart';
import 'package:comunic/models/survey.dart';
import 'package:comunic/models/survey_choice.dart';
import 'package:meta/meta.dart';

/// Survey helper
///
/// @author Pierre HUBERT

class SurveyHelper {
  /// Cancel the response of a user to a survey
  Future<bool> cancelResponse(Survey survey) async {
    return (await APIRequest(
            uri: "surveys/cancel_response",
            needLogin: true,
            args: {"postID": survey.postID.toString()}).exec())
        .isOK;
  }

  /// Send the response of a user to a survey
  Future<bool> respondToSurvey(
      {@required Survey survey, @required SurveyChoice choice}) async {
    assert(survey != null);
    assert(choice != null);

    return (await APIRequest(
      uri: "surveys/send_response",
      needLogin: true,
      args: {
        "postID": survey.postID.toString(),
        "choiceID": choice.id.toString(),
      },
    ).exec())
        .isOK;
  }

  /// Turn an API entry into a [Survey] object
  static Survey apiToSurvey(Map<String, dynamic> map) {
    // Parse survey responses
    Set<SurveyChoice> choices = Set();

    map["choices"].forEach((k, e) => choices.add(SurveyChoice(
        id: e["choiceID"], name: e["name"], responses: e["responses"])));

    return Survey(
      id: map["ID"],
      userID: map["userID"],
      postID: map["postID"],
      creationTime: map["creation_time"],
      question: map["question"],
      userChoice: map["user_choice"],
      choices: choices,
    );
  }
}
